@@ -46,7 +46,7 @@ NULL
 #'
 #' @param numeric_focus `logical` should extra attention be paid
 #'   to verifying the accuracy of numerical calculations? This may be
-#'   useful when dealing problems that may suffer from numerical instability
+#'   useful when dealing with problems that may suffer from numerical instability
 #'   issues. Beware that it will likely substantially increase run time
 #'   (sets the *Gurobi* `NumericFocus` parameter
 #'   to 3). Defaults to `FALSE`.
@@ -67,7 +67,9 @@ NULL
 #'   to store information on disk when solving a given problem.
 #'
 #' @param start_solution `NULL` or object containing the starting solution
-#'   for the solver. Defaults to `NULL` such that no starting solution is used.
+#'   for the solver. This is can be useful because specifying a starting
+#'   solution can speed up the optimization process.
+#'   Defaults to `NULL` such that no starting solution is used.
 #'   To specify a starting solution, the argument to `start_solution` should
 #'   be in the same format as the planning units (i.e., a `NULL`, `numeric`,
 #'   `matrix`, `data.frame`, [terra::rast()], or [sf::sf()] object).
@@ -167,16 +169,16 @@ add_gurobi_solver <- function(x, gap = 0.1, time_limit = .Machine$integer.max,
                               numeric_focus = FALSE, node_file_start = Inf,
                               start_solution = NULL, verbose = TRUE) {
   # assert that arguments are valid (except start_solution)
-  rlang::check_required(x)
-  rlang::check_required(gap)
-  rlang::check_required(time_limit)
-  rlang::check_required(presolve)
-  rlang::check_required(threads)
-  rlang::check_required(first_feasible)
-  rlang::check_required(numeric_focus)
-  rlang::check_required(node_file_start)
-  rlang::check_required(start_solution)
-  rlang::check_required(verbose)
+  assert_required(x)
+  assert_required(gap)
+  assert_required(time_limit)
+  assert_required(presolve)
+  assert_required(threads)
+  assert_required(first_feasible)
+  assert_required(numeric_focus)
+  assert_required(node_file_start)
+  assert_required(start_solution)
+  assert_required(verbose)
   assert(
     is_conservation_problem(x),
     assertthat::is.number(gap),
