@@ -12,7 +12,7 @@ extern SEXP _prioritizr_rcpp_absolute_amount_held_by_solution(SEXP, SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_add_rij_data(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_add_zones_constraints(SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_apply_asym_connectivity_penalties(SEXP, SEXP, SEXP);
-extern SEXP _prioritizr_rcpp_apply_boundary_penalties(SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _prioritizr_rcpp_apply_boundary_penalties(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_apply_bounded_constraints(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_apply_connectivity_penalties(SEXP, SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_apply_contiguity_constraints(SEXP, SEXP, SEXP);
@@ -31,8 +31,7 @@ extern SEXP _prioritizr_rcpp_apply_min_set_objective(SEXP, SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_apply_min_shortfall_objective(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_apply_neighbor_constraints(SEXP, SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_asym_connectivity(SEXP, SEXP);
-extern SEXP _prioritizr_rcpp_boundary(SEXP, SEXP, SEXP, SEXP);
-extern SEXP _prioritizr_rcpp_boundary_data(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _prioritizr_rcpp_boundary(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_branch_matrix(SEXP);
 extern SEXP _prioritizr_rcpp_connectivity(SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_ferrier_score(SEXP, SEXP, SEXP, SEXP);
@@ -59,15 +58,13 @@ extern SEXP _prioritizr_rcpp_new_optimization_problem(SEXP, SEXP, SEXP);
 extern SEXP _prioritizr_rcpp_optimization_problem_as_list(SEXP);
 extern SEXP _prioritizr_rcpp_predefined_optimization_problem(SEXP);
 extern SEXP _prioritizr_rcpp_set_optimization_problem_shuffled(SEXP);
-extern SEXP _prioritizr_rcpp_sp_to_polyset(SEXP, SEXP, SEXP);
-extern SEXP _prioritizr_rcpp_summarize_exactextractr(SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"_prioritizr_rcpp_absolute_amount_held_by_solution",                  (DL_FUNC) &_prioritizr_rcpp_absolute_amount_held_by_solution,                  3},
     {"_prioritizr_rcpp_add_rij_data",                                      (DL_FUNC) &_prioritizr_rcpp_add_rij_data,                                      4},
     {"_prioritizr_rcpp_add_zones_constraints",                             (DL_FUNC) &_prioritizr_rcpp_add_zones_constraints,                             2},
     {"_prioritizr_rcpp_apply_asym_connectivity_penalties",                 (DL_FUNC) &_prioritizr_rcpp_apply_asym_connectivity_penalties,                 3},
-    {"_prioritizr_rcpp_apply_boundary_penalties",                          (DL_FUNC) &_prioritizr_rcpp_apply_boundary_penalties,                          5},
+    {"_prioritizr_rcpp_apply_boundary_penalties",                          (DL_FUNC) &_prioritizr_rcpp_apply_boundary_penalties,                          7},
     {"_prioritizr_rcpp_apply_bounded_constraints",                         (DL_FUNC) &_prioritizr_rcpp_apply_bounded_constraints,                         5},
     {"_prioritizr_rcpp_apply_connectivity_penalties",                      (DL_FUNC) &_prioritizr_rcpp_apply_connectivity_penalties,                      3},
     {"_prioritizr_rcpp_apply_contiguity_constraints",                      (DL_FUNC) &_prioritizr_rcpp_apply_contiguity_constraints,                      3},
@@ -86,8 +83,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"_prioritizr_rcpp_apply_min_shortfall_objective",                     (DL_FUNC) &_prioritizr_rcpp_apply_min_shortfall_objective,                     4},
     {"_prioritizr_rcpp_apply_neighbor_constraints",                        (DL_FUNC) &_prioritizr_rcpp_apply_neighbor_constraints,                        3},
     {"_prioritizr_rcpp_asym_connectivity",                                 (DL_FUNC) &_prioritizr_rcpp_asym_connectivity,                                 2},
-    {"_prioritizr_rcpp_boundary",                                          (DL_FUNC) &_prioritizr_rcpp_boundary,                                          4},
-    {"_prioritizr_rcpp_boundary_data",                                     (DL_FUNC) &_prioritizr_rcpp_boundary_data,                                     4},
+    {"_prioritizr_rcpp_boundary",                                          (DL_FUNC) &_prioritizr_rcpp_boundary,                                          6},
     {"_prioritizr_rcpp_branch_matrix",                                     (DL_FUNC) &_prioritizr_rcpp_branch_matrix,                                     1},
     {"_prioritizr_rcpp_connectivity",                                      (DL_FUNC) &_prioritizr_rcpp_connectivity,                                      2},
     {"_prioritizr_rcpp_ferrier_score",                                     (DL_FUNC) &_prioritizr_rcpp_ferrier_score,                                     4},
@@ -114,8 +110,6 @@ static const R_CallMethodDef CallEntries[] = {
     {"_prioritizr_rcpp_optimization_problem_as_list",                      (DL_FUNC) &_prioritizr_rcpp_optimization_problem_as_list,                      1},
     {"_prioritizr_rcpp_predefined_optimization_problem",                   (DL_FUNC) &_prioritizr_rcpp_predefined_optimization_problem,                   1},
     {"_prioritizr_rcpp_set_optimization_problem_shuffled",                 (DL_FUNC) &_prioritizr_rcpp_set_optimization_problem_shuffled,                 1},
-    {"_prioritizr_rcpp_sp_to_polyset",                                     (DL_FUNC) &_prioritizr_rcpp_sp_to_polyset,                                     3},
-    {"_prioritizr_rcpp_summarize_exactextractr",                           (DL_FUNC) &_prioritizr_rcpp_summarize_exactextractr,                           4},
     {NULL, NULL, 0}
 };
 
