@@ -1,5 +1,3 @@
-context("add_linear_penalties")
-
 test_that("minimum set objective (numeric, compile, single zone)", {
   # import data
   sim_pu_raster <- get_sim_pu_raster()
@@ -101,11 +99,14 @@ test_that("minimum set objective (character/Spatial, compile, single zone)", {
   sim_pu_polygons$penalty_data <- runif(nrow(sim_pu_polygons)) * 3
   # create problems
   expect_warning(
-    p1 <-
-      problem(sim_pu_polygons, sim_features, cost_column = "cost") %>%
-      add_min_set_objective() %>%
-      add_relative_targets(0.1) %>%
-      add_binary_decisions(),
+    expect_warning(
+      p1 <-
+        problem(sim_pu_polygons, sim_features, cost_column = "cost") %>%
+        add_min_set_objective() %>%
+        add_relative_targets(0.1) %>%
+        add_binary_decisions(),
+      "deprecated"
+    ),
     "deprecated"
   )
   p2 <-
@@ -365,14 +366,17 @@ test_that("minimum set objective (character/Spatial, compile, multiple zones)",
   )
   # create problems
   expect_warning(
-    p1 <-
-      problem(
-        sim_zones_pu_polygons, sim_zones_features,
-        cost_column = c("cost_1", "cost_2", "cost_3")
-      ) %>%
-      add_min_set_objective() %>%
-      add_absolute_targets(targ) %>%
-      add_binary_decisions(),
+    expect_warning(
+      p1 <-
+        problem(
+          sim_zones_pu_polygons, sim_zones_features,
+          cost_column = c("cost_1", "cost_2", "cost_3")
+        ) %>%
+        add_min_set_objective() %>%
+        add_absolute_targets(targ) %>%
+        add_binary_decisions(),
+      "deprecated"
+    ),
     "deprecated"
   )
   p2 <-
@@ -523,7 +527,7 @@ test_that("minimum set objective (solve, multiple zones)", {
   # solve problem
   s <- solve(p)
   # tests
-  expect_is(s, "SpatRaster")
+  expect_inherits(s, "SpatRaster")
   expect_equal(c(terra::values(s[[1]])), c(0, 1, NA, 1, 0, 0, NA))
   expect_equal(c(terra::values(s[[2]])), c(1, 0, 0,  0, 0, 0, NA))
 })
@@ -532,6 +536,8 @@ test_that("invalid inputs", {
   # import data
   sim_pu_raster <- get_sim_pu_raster()
   sim_features <- get_sim_features()
+  sim_pu_polygons <- get_sim_pu_polygons()
+  # tests
   expect_tidy_error({
     problem(sim_pu_raster, sim_features) %>%
     add_linear_penalties(NA_real_, sim_features[[1]])
