@@ -1,5 +1,3 @@
-context("branch matrix")
-
 test_that("phylo input", {
   # create data
   phy <- structure(
@@ -31,7 +29,7 @@ test_that("phylo input", {
   s[5, c(8, 6)] <- 1
   s <- as_Matrix(s, "dgCMatrix")
   # tests
-  expect_is(m, "dgCMatrix")
+  expect_inherits(m, "dgCMatrix")
   expect_true(all(m == s))
 })
 
@@ -39,5 +37,4 @@ test_that("invalid input", {
   tr <- ape::rtree(3)
   tr$edge[1] <- 0
   expect_tidy_error(branch_matrix(tr))
-  expect_tidy_error(branch_matrix("a"))
 })
