@@ -1,5 +1,3 @@
-context("marxan_connectivity_data_to_matrix")
-
 test_that("single zone (x = NULL, symmetric = TRUE)", {
   # create data
   d <- expand.grid(id1 = seq_len(4), id2 = c(1, 4))
@@ -16,7 +14,7 @@ test_that("single zone (x = NULL, symmetric = TRUE)", {
   x2[1, 1] <- 0.5
   x2[4, 4] <- 0.5
   # tests
-  expect_is(x, "dsCMatrix")
+  expect_inherits(x, "dsCMatrix")
   expect_equal(x, as_Matrix(x2, "dsCMatrix"))
 })
 
@@ -39,7 +37,7 @@ test_that("multiple zones (x = NULL, symmetric = TRUE)", {
     x2[d$id1[i], d$id2[i], curr_z1, curr_z2] <- d$boundary[i]
   }
   # tests
-  expect_is(x, "array")
+  expect_inherits(x, "array")
   expect_equal(x, x2)
 })
 
@@ -64,7 +62,7 @@ test_that("single zone (x = ConservationProblem, symmetric = TRUE)", {
   x2[1, 1] <- 0.5
   x2[4, 4] <- 0.5
   # tests
-  expect_is(x, "dsCMatrix")
+  expect_inherits(x, "dsCMatrix")
   expect_equal(x, as_Matrix(x2, "dsCMatrix"))
 })
 
@@ -95,7 +93,7 @@ test_that("multiple zones (x = ConservationProblem, symmetric = TRUE)", {
     x2[d$id1[i], d$id2[i], curr_z1, curr_z2] <- d$boundary[i]
   }
   # tests
-  expect_is(x, "array")
+  expect_inherits(x, "array")
   expect_equal(x, x2)
 })
 
@@ -110,7 +108,7 @@ test_that("single zone (x = NULL, symmetric = FALSE)", {
   x2[2, 1] <- 5
   x2[2, 3] <- 6
   # tests
-  expect_is(x, "dgCMatrix")
+  expect_inherits(x, "dgCMatrix")
   expect_equal(x, as_Matrix(x2, "dgCMatrix"))
 })
 
@@ -133,7 +131,7 @@ test_that("multiple zones (x = NULL, symmetric = FALSE)", {
     x2[d$id1[i], d$id2[i], curr_z1, curr_z2] <- d$boundary[i]
   }
   # tests
-  expect_is(x, "array")
+  expect_inherits(x, "array")
   expect_equal(x, x2)
 })
 
@@ -153,7 +151,7 @@ test_that("single zone (x = ConservationProblem, symmetric = FALSE)", {
   x2[2, 1] <- 5
   x2[2, 3] <- 6
   # tests
-  expect_is(x, "dgCMatrix")
+  expect_inherits(x, "dgCMatrix")
   expect_equal(x, as_Matrix(x2, "dgCMatrix"))
 })
 
@@ -184,6 +182,6 @@ test_that("multiple zones (x = ConservationProblem, symmetric = FALSE)", {
     x2[d$id1[i], d$id2[i], curr_z1, curr_z2] <- d$boundary[i]
   }
   # tests
-  expect_is(x, "array")
+  expect_inherits(x, "array")
   expect_equal(x, x2)
 })
